@@ -1,4 +1,3 @@
-context("generateThreshVsPerf")
 
 test_that("generateThreshVsPerfData", {
 
@@ -10,42 +9,46 @@ test_that("generateThreshVsPerfData", {
   plotThreshVsPerf(pvs)
   dir = tempdir()
   path = file.path(dir, "test.svg")
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)), equals(length(pvs$measures)))
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(length(pvs$measures)))
+  expect_equal(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)), length(pvs$measures))
+  expect_equal(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), length(pvs$measures))
 
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE)
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(1L))
+  expect_equal(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), 1L)
 
   ## resample prediction
   rdesc = makeResampleDesc("CV", iters = 2L)
   r = resample(lrn, binaryclass.task, rdesc)
   pvs = generateThreshVsPerfData(r, list(tpr, fpr))
   plotThreshVsPerf(pvs, pretty.names = FALSE)
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)), equals(length(pvs$measures)))
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(length(pvs$measures)))
+  expect_equal(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)),
+               length(pvs$measures))
+  expect_equal(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)),
+               length(pvs$measures))
 
   pvs = generateThreshVsPerfData(r, list(tpr, fpr, acc), aggregate = FALSE)
   plotThreshVsPerf(pvs, measures = list(tpr, fpr, acc))
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(length(pvs$measures) * length(unique(pvs$data$iter))))
+  expect_equal(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)),
+              length(pvs$measures) * length(unique(pvs$data$iter)))
 
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE)
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(length(unique(pvs$data$iter))))
+  expect_equal(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)),
+              length(unique(pvs$data$iter)))
 
   pvs = generateThreshVsPerfData(r, list(tpr, fpr), aggregate = FALSE)
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE)
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(rdesc$iters))
+  expect_equal(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), rdesc$iters)
 
   ## benchmark result
   lrns = list(lrn, makeLearner("classif.lda", predict.type = "prob"))
@@ -54,64 +57,64 @@ test_that("generateThreshVsPerfData", {
     measures = getDefaultMeasure(binaryclass.task))
   pvs = generateThreshVsPerfData(res, list(tpr, fpr))
   plotThreshVsPerf(pvs)
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)), equals(length(pvs$measures)))
-  expect_that(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)), equals(length(unique(pvs$data$learner))))
-  expect_that(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)), equals(length(unique(pvs$data$learner))))
+  expect_equal(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)), length(pvs$measures))
+  expect_equal(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)), length(unique(pvs$data$learner)))
+  expect_equal(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)), length(unique(pvs$data$learner)))
 
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE, facet.learner = TRUE)
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(length(unique(pvs$data$learner))))
+  expect_equal(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), length(unique(pvs$data$learner)))
 
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE, facet.learner = FALSE)
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)), equals(1))
-  expect_that(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)), equals(1))
+  expect_equal(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)), 1)
+  expect_equal(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)), 1)
 
   pvs = generateThreshVsPerfData(res, list(tpr, fpr), aggregate = FALSE)
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE, facet.learner = TRUE)
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(rdesc$iters * length(unique(pvs$data$learner))))
+  expect_equal(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), rdesc$iters * length(unique(pvs$data$learner)))
 
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE, facet.learner = FALSE)
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)), equals(rdesc$iters))
-  expect_that(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)), equals(rdesc$iters))
+  expect_equal(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)), rdesc$iters)
+  expect_equal(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)), rdesc$iters)
 
   ## list of resample predictions
   rs = lapply(lrns, crossval, task = binaryclass.task, iters = 2L)
   names(rs) = c("a", "b")
   pvs = generateThreshVsPerfData(rs, list(tpr, fpr))
   plotThreshVsPerf(pvs)
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)), equals(length(pvs$measures)))
-  expect_that(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)), equals(length(unique(pvs$data$learner))))
-  expect_that(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)), equals(length(unique(pvs$data$learner))))
+  expect_equal(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)), length(pvs$measures))
+  expect_equal(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)), length(unique(pvs$data$learner)))
+  expect_equal(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)), length(unique(pvs$data$learner)))
 
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE, facet.learner = TRUE)
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)), equals(length(unique(pvs$data$learner))))
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(length(unique(pvs$data$learner))))
+  expect_equal(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)), length(unique(pvs$data$learner)))
+  expect_equal(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), length(unique(pvs$data$learner)))
 
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE, facet.learner = FALSE)
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)), equals(1))
-  expect_that(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)), equals(1))
+  expect_equal(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)), 1)
+  expect_equal(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)), 1)
 
   pvs = generateThreshVsPerfData(rs, list(tpr, fpr), aggregate = FALSE)
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE, facet.learner = TRUE)
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)), equals(length(unique(pvs$data$learner))))
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(rdesc$iters * length(unique(pvs$data$learner))))
+  expect_equal(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)), length(unique(pvs$data$learner)))
+  expect_equal(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), rdesc$iters * length(unique(pvs$data$learner)))
 
   ## test prediction obj with custom measure
   classes = levels(getTaskTargets(binaryclass.task))
@@ -121,9 +124,9 @@ test_that("generateThreshVsPerfData", {
     minimize = TRUE, costs = mcm, combine = mean)
   pvs.custom = generateThreshVsPerfData(pred, costs)
   plotThreshVsPerf(pvs.custom)
-  ggplot2::ggsave(path)
+  suppressMessages(ggsave(path))
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(1L))
+  expect_equal(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), 1L)
 
   # test that facetting works for plotThreshVsPerf
 
