@@ -1,7 +1,6 @@
-context("classif_rrlda")
 
 test_that("classif_rrlda", {
-  requirePackagesOrSkip("!rrlda", default.method = "load")
+  suppressMessages(requirePackagesOrSkip("!rrlda", default.method = "load"))
 
   m = rrlda::rrlda(x = multiclass.train[, -multiclass.class.col],
     grouping = multiclass.train[, multiclass.target])
