@@ -1,4 +1,3 @@
-context("learners_classiflabelswitch")
 
 n = 50L
 p = 2L
@@ -84,11 +83,11 @@ test_that("no labels are switched", {
   }
   # FIXME: only check prob for now for timing reasons
   for (predtype in "prob") {
-    checkErrsForTask(mytask1a, predtype)
-    checkErrsForTask(mytask1b, predtype)
-    checkErrsForTask(mytask2a, predtype)
-    checkErrsForTask(mytask2b, predtype)
-    checkErrsForTask(mytask3, predtype)
-    checkErrsForTask(mytask4, predtype)
+    suppressWarnings(checkErrsForTask(mytask1a, predtype))
+    suppressWarnings(checkErrsForTask(mytask1b, predtype))
+    suppressWarnings(checkErrsForTask(mytask2a, predtype))
+    suppressWarnings(checkErrsForTask(mytask2b, predtype))
+    suppressWarnings(checkErrsForTask(mytask3, predtype))
+    suppressWarnings(checkErrsForTask(mytask4, predtype))
   }
 })
